@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.61 2003/05/31 05:54:47 dcransto Exp $ */
+/* $Id: gdict-app.c,v 1.62 2003/11/10 01:49:50 gman Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -146,8 +146,11 @@ void
 gdict_open_speller (void) 
 {
     if (!speller) {
-        speller = GDICT_SPELLER (gdict_speller_new (context));
-        
+        speller = GDICT_SPELLER (gdict_speller_new ());
+
+	speller->context = context;
+	gdict_speller_reset_strat (speller);
+
         if (!speller) return;
 
         gtk_signal_connect (GTK_OBJECT (speller), "word_lookup_start",
