@@ -1,4 +1,4 @@
-/* $Id: gdict-applet.c,v 1.50 2003/09/18 23:08:09 jirka Exp $ */
+/* $Id: gdict-applet.c,v 1.51 2003/12/31 21:17:09 gman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -344,6 +344,7 @@ gdict_applet_new (PanelApplet *parent_applet)
 {
 	GDictApplet *applet;
 	BonoboUIComponent *component;
+	GtkIconInfo *icon_info;
  	
  	applet = g_new0 (GDictApplet, 1);
  	
@@ -351,7 +352,11 @@ gdict_applet_new (PanelApplet *parent_applet)
 	applet->panel_size = panel_applet_get_size (PANEL_APPLET (applet->applet_widget));
  	applet->orient = panel_applet_get_orient (PANEL_APPLET (applet->applet_widget));
 	
- 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gdict.png");
+	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), "gdict", 48, 0);
+	if (icon_info) {
+		gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+	}
  	
 	panel_applet_set_flags (parent_applet, PANEL_APPLET_EXPAND_MINOR);
 
