@@ -25,16 +25,11 @@
  *
  */
 
-#define ICON_SIZE 24.0
 #define GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE 48
 #define GNOME_SEARCH_TOOL_STOCK "panel-searchtool"
+#define GNOME_SEARCH_TOOL_REFRESH_DURATION  50000
 #define LEFT_LABEL_SPACING "     "
 
-#define DEFAULT_ANIMATION_WIDTH   48
-#define DEFAULT_ANIMATION_HEIGHT  48
-#define DEFAULT_ANIMATION_FRAME    2
-#define TOTAL_ANIMATION_FRAMES     3
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -50,12 +45,14 @@
 #include "gsearchtool.h"
 #include "gsearchtool-support.h"
 #include "gsearchtool-callbacks.h"
+#include "gsearchtool-alert-dialog.h"
+#include "gsearchtool-spinner.h"
 
 #include <string.h>
 #include <unistd.h>
 #include <signal.h>
 #include <libbonobo.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
@@ -86,7 +83,7 @@ static FindOptionTemplate templates[] = {
 	{ SEARCH_CONSTRAINT_TEXT, "'!' -name '*%s*'", N_("Na_me does not contain"), FALSE },
 	{ SEARCH_CONSTRAINT_TEXT, "-regex '%s'", N_("Name matches regular e_xpression"), FALSE }, 
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
-	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden files and folders"), FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden and backup files"), FALSE },
 	{ SEARCH_CONSTRAINT_BOOL, "-follow", N_("Follow symbolic links"), FALSE },
 	{ SEARCH_CONSTRAINT_BOOL, "INCLUDE_OTHER_FILESYSTEMS", N_("Include other filesystems"), FALSE },
 	{ SEARCH_CONSTRAINT_END, NULL, NULL, FALSE}
@@ -313,7 +310,8 @@ build_search_command (void)
 	command = g_string_new ("");
 	search_command.show_hidden_files = FALSE;
 	
-	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) {
+	if ((GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) ||
+	    (interface.selected_constraints == NULL)) {
 	
 		gchar *locate;
 		gboolean disable_quick_search;
@@ -326,6 +324,9 @@ build_search_command (void)
 		if ((disable_quick_search != TRUE) && (locate != NULL) 
 		    && (is_path_in_home_folder (look_in_folder_locale) != TRUE) 
 		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)
+		    && (is_path_in_proc_folder (look_in_folder_locale) != TRUE) 
+		    && (is_path_in_dev_folder (look_in_folder_locale) != TRUE)
+		    && (is_path_in_var_folder (look_in_folder_locale) != TRUE)
 		    && (is_path_in_tmp_folder (look_in_folder_locale) != TRUE)) {	
 			g_string_append_printf (command, "%s %s '%s*%s'", 
 						locate,
@@ -445,46 +446,24 @@ add_file_to_search_results (const gchar 	*file,
 			    GtkListStore 	*store, 
 			    GtkTreeIter 	*iter)
 {					
-	gchar *mime_type = gnome_vfs_get_mime_type (file);
-	gchar *description = get_file_type_with_mime_type (file, mime_type);
-	gchar *icon_path = get_file_icon_with_mime_type (file, mime_type);
-	GnomeVFSFileInfo *vfs_file_info = gnome_vfs_file_info_new ();
-	GdkPixbuf *pixbuf = NULL;
+	const char *mime_type; 
+	const char *description;
+	GdkPixbuf *pixbuf;
+	GnomeVFSFileInfo *vfs_file_info;
 	gchar *readable_size, *readable_date;
 	gchar *utf8_base_name, *utf8_dir_name;
 	gchar *base_name, *dir_name;
 	
+	mime_type = gnome_vfs_get_file_mime_type (file, NULL, FALSE);
+	 
+	description = get_file_type_for_mime_type (file, mime_type);
+	pixbuf = get_file_pixbuf_for_mime_type (file, mime_type);
+	
 	if (gtk_tree_view_get_headers_visible (GTK_TREE_VIEW(interface.tree)) == FALSE) {
 		gtk_tree_view_set_headers_visible (GTK_TREE_VIEW(interface.tree), TRUE);
 	}
 	
-	if (icon_path != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
-	}
-	
-	if (pixbuf != NULL) {
-		GdkPixbuf *scaled;
-		int        new_w, new_h;
-		int        w, h;
-		double     factor;
-
-		/* scale keeping aspect ratio. */
-
-		w = gdk_pixbuf_get_width (pixbuf);
-		h = gdk_pixbuf_get_height (pixbuf);
-			
-		factor = MIN (ICON_SIZE / w, ICON_SIZE / h);
-		new_w  = MAX ((int) (factor * w), 1);
-		new_h  = MAX ((int) (factor * h), 1);
-			
-		scaled = gdk_pixbuf_scale_simple (pixbuf,
-						  new_w,
-						  new_h,
-						  GDK_INTERP_BILINEAR);
-						  				  
-		g_object_unref (G_OBJECT (pixbuf));
-		pixbuf = scaled;       	
-	}
+	vfs_file_info = gnome_vfs_file_info_new ();
 	gnome_vfs_get_file_info (file, vfs_file_info, GNOME_VFS_FILE_INFO_DEFAULT);
 	readable_size = gnome_vfs_format_file_size_for_display (vfs_file_info->size);
 	readable_date = get_readable_date (vfs_file_info->mtime);
@@ -502,23 +481,17 @@ add_file_to_search_results (const gchar 	*file,
 			    COLUMN_PATH, utf8_dir_name,
 			    COLUMN_READABLE_SIZE, readable_size,
 			    COLUMN_SIZE, (-1) * (gdouble) vfs_file_info->size,
-			    COLUMN_TYPE, description,
+			    COLUMN_TYPE, (description != NULL) ? description : mime_type,
 			    COLUMN_READABLE_DATE, readable_date,
 			    COLUMN_DATE, (-1) * (gdouble) vfs_file_info->mtime,
 			    COLUMN_NO_FILES_FOUND, FALSE,
 			    -1);
 
-	if (pixbuf != NULL) {
-		g_object_unref (G_OBJECT(pixbuf));
-	}
-
 	gnome_vfs_file_info_unref (vfs_file_info);
 	g_free (base_name);
 	g_free (dir_name);
-	g_free (mime_type);
 	g_free (utf8_base_name);
 	g_free (utf8_dir_name);
-	g_free (icon_path); 
 	g_free (readable_size);
 	g_free (readable_date);
 }
@@ -564,15 +537,17 @@ update_search_counts (void)
 		message_string = g_strdup (_("No files found"));
 		add_no_files_found_message (interface.model, &interface.iter);
 	}
-	else if (total_files == 1) {
-		title_bar_string = g_strdup (_("One File Found"));
-		message_string = g_strdup (_("One file found"));
-	}
 	else {
-		title_bar_string = g_strdup_printf (_("%d Files Found"), total_files);
-		message_string = g_strdup_printf (_("%d files found"), total_files);
+		title_bar_string = g_strdup_printf (ngettext ("%d File Found",
+					                      "%d Files Found",
+					                      total_files),
+						    total_files);
+		message_string = g_strdup_printf (ngettext ("%d file found",
+					                    "%d files found",
+					                    total_files),
+						  total_files);
 	}
-		
+
 	if (strlen (stopped_string) > 0) {
 		tmp = message_string;
 		message_string = g_strconcat (message_string, " ", stopped_string, NULL);
@@ -917,69 +892,6 @@ get_desktop_item_name (void)
 	return g_string_free (gs, FALSE);
 }
 
-static gboolean
-setup_animation_image (void)
-{
-	gint	   width  = 0;
-	gint	   height = 0;
-	GError     *error = NULL;
-
-	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
-
-	interface.pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/gnome-search-tool/gnome-search-tool-animation.png",
-	                                             &error);
-	
-	if (error) {
-		g_warning (_("The animation file is missing or invalid: %s"), error->message);		
-		g_error_free (error);
-		gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), 0, 0);
-		return FALSE;
-	}
-
-	width  = gdk_pixbuf_get_width (interface.pixbuf); 
-	height = gdk_pixbuf_get_height (interface.pixbuf); 
-
-	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area), width / TOTAL_ANIMATION_FRAMES, height);
-	gtk_widget_queue_draw (interface.drawing_area); 
-
-	return TRUE;
-}
-
-static gboolean
-animation_expose_event_cb (GtkWidget       *widget,
-                           GdkEventExpose  *event,
-                           gpointer        *data)
-{
-	gint width  = 0;
-	gint height = 0;
-
-	if (interface.pixbuf == NULL) {
-		return FALSE;
-	}
-
-	gdk_window_clear_area (widget->window,
-	                       event->area.x, event->area.y,
-	                       event->area.width, event->area.height);
-
-	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], &event->area); 
-
-	width  = gdk_pixbuf_get_width (interface.pixbuf); 
-	height = gdk_pixbuf_get_height (interface.pixbuf); 
-
-	gdk_pixbuf_render_to_drawable_alpha (interface.pixbuf,
-	                                     GDK_DRAWABLE (widget->window),
-	                                     (width * interface.current_animation_frame) / TOTAL_ANIMATION_FRAMES, 0, 
-	                                     0, 0,
-	                                     width / TOTAL_ANIMATION_FRAMES, height,
-	                                     GDK_PIXBUF_ALPHA_FULL, 255,
-	                                     GDK_RGB_DITHER_MAX,
-	                                     0, 0);
-
-	gdk_gc_set_clip_rectangle (widget->style->fg_gc[widget->state], NULL);
-
-        return FALSE;
-}
-
 static void
 start_animation (void)
 {
@@ -989,7 +901,7 @@ start_animation (void)
 	gtk_window_set_title (GTK_WINDOW (interface.main_window), title);
 	
 	gtk_label_set_text (GTK_LABEL (interface.results_label), "");
-	search_command.animation_timeout = g_timeout_add (250, update_animation_timeout_cb, NULL);
+	gsearch_spinner_start (GSEARCH_SPINNER (interface.spinner));
 	
 	g_free (title);
 } 
@@ -997,34 +909,9 @@ start_animation (void)
 static void
 stop_animation (void)
 {
-	interface.current_animation_frame = DEFAULT_ANIMATION_FRAME - 1;
-	g_source_remove (search_command.animation_timeout);
-	gtk_widget_queue_draw (interface.drawing_area);
+	gsearch_spinner_stop (GSEARCH_SPINNER (interface.spinner));
 } 
 
-gboolean
-update_animation_timeout_cb (gpointer data)
-{
-	static gboolean in_forward_progress = TRUE;
-	
-	if (in_forward_progress) {
-		interface.current_animation_frame++;
-		if (interface.current_animation_frame >= (TOTAL_ANIMATION_FRAMES - 1)) {
-			in_forward_progress = !in_forward_progress;
-		}
-	}
-	else {
-		interface.current_animation_frame--;
-		if (interface.current_animation_frame <= 0) {
-			in_forward_progress = !in_forward_progress;
-		}
-	}
-		      
-	gtk_widget_queue_draw (interface.drawing_area);
-
-	return TRUE;
-}
-
 void
 define_popt_descriptions (void) 
 {
@@ -1177,14 +1064,19 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 	if ((condition == G_IO_IN) || (condition == G_IO_IN + G_IO_HUP)) { 
 	
 		GError       *error = NULL;
+		GTimer       *timer;
 		GString      *string;
 		GdkRectangle prior_rect;
 		GdkRectangle after_rect;
+		gulong       duration;
 		gint	     look_in_folder_string_length;
 		
 		string = g_string_new (NULL);
 		look_in_folder_string_length = strlen (search_data->look_in_folder);
 
+		timer = g_timer_new();
+		g_timer_start (timer);
+
 		while (ioc->is_readable != TRUE);
 
 		do {
@@ -1206,12 +1098,13 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 				if (status == G_IO_STATUS_EOF) {
 					broken_pipe = TRUE;
 				}
-				
-				while (gtk_events_pending ()) {
-					if (search_data->running == MAKE_IT_QUIT) {
-						return FALSE;
+				else if (status == G_IO_STATUS_AGAIN) {
+					while (gtk_events_pending ()) {
+						if (search_data->running == MAKE_IT_QUIT) {
+							return FALSE;
+						}
+						gtk_main_iteration (); 				
 					}
-					gtk_main_iteration (); 				
 				}
 				
 			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
@@ -1253,7 +1146,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							}
 						}
-						else if (is_path_hidden (string->str) == FALSE) {
+						else if ((is_path_hidden (string->str) == FALSE) && (!file_extension_is (string->str, "~"))) {
 							if (search_data->regex_matching_enabled == FALSE) {
 								add_file_to_search_results (string->str, interface.model, &interface.iter);
 							} 
@@ -1266,26 +1159,32 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 			}
 			g_free (utf8);
 			g_free (filename);
-			
+
 			gtk_tree_view_get_visible_rect (GTK_TREE_VIEW(interface.tree), &prior_rect);
 			
-			while (gtk_events_pending ()) {
-				if (search_data->running == MAKE_IT_QUIT) {
-					return FALSE;
-				}
-				gtk_main_iteration (); 				
-			}
-			
 			if (prior_rect.y == 0) {
 				gtk_tree_view_get_visible_rect (GTK_TREE_VIEW(interface.tree), &after_rect);
 				if (after_rect.y <= 40) {  /* limit this hack to the first few pixels */
 					gtk_tree_view_scroll_to_point (GTK_TREE_VIEW(interface.tree), -1, 0);
+				}	
+			}
+
+			g_timer_elapsed (timer, &duration);
+
+			if (duration > GNOME_SEARCH_TOOL_REFRESH_DURATION) {
+				while (gtk_events_pending ()) {
+					if (search_data->running == MAKE_IT_QUIT) {
+						return FALSE;
+					}
+					gtk_main_iteration ();		
 				}
-			}	
+				g_timer_reset (timer);
+			}
 			
 		} while (g_io_channel_get_buffer_condition (ioc) == G_IO_IN);
 		
 		g_string_free (string, TRUE);
+		g_timer_destroy (timer);
 	}
 
 	if (condition != G_IO_IN || broken_pipe == TRUE) { 
@@ -1297,6 +1196,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		search_data->lock = FALSE;
 		search_data->running = NOT_RUNNING;
 		search_data->not_running_timeout = TRUE;
+		g_hash_table_destroy (search_data->pixbuf_hash);
 		g_timeout_add (500, not_running_timeout_cb, NULL);
 
 		update_search_counts ();
@@ -1304,7 +1204,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 
 		gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.find_button);
 		gtk_widget_set_sensitive (interface.additional_constraints, TRUE);
-		gtk_widget_set_sensitive (interface.checkbutton, TRUE);
+		gtk_widget_set_sensitive (interface.expander, TRUE);
 		gtk_widget_set_sensitive (interface.table, TRUE);
 		gtk_widget_set_sensitive (interface.find_button, TRUE);
 		gtk_widget_hide (interface.stop_button);
@@ -1349,14 +1249,15 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 				if (status == G_IO_STATUS_EOF) {
 					broken_pipe = TRUE;
 				}
-	
-				while (gtk_events_pending ()) {
-					if (search_data->running == MAKE_IT_QUIT) {
-						break;
+				else if (status == G_IO_STATUS_AGAIN) {
+					while (gtk_events_pending ()) {
+						if (search_data->running == MAKE_IT_QUIT) {
+							break;
+						}
+						gtk_main_iteration ();
 					}
-					gtk_main_iteration ();
 				}
-					
+				
 			} while (status == G_IO_STATUS_AGAIN && broken_pipe == FALSE);
 			
 			if (broken_pipe == TRUE) {
@@ -1404,11 +1305,13 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 				     		_("\n... Too many errors to display ..."));
 				}
 				
-				dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-				                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-								     GTK_BUTTONS_OK,
-				                                     _("Error while searching for files"),
-				                                     error_msgs->str);
+				dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+		                	                           GTK_DIALOG_DESTROY_WITH_PARENT,
+						                   GTK_MESSAGE_ERROR,
+							           GTK_BUTTONS_OK,
+							           _("Error while searching for files."),
+							           error_msgs->str,
+							           NULL);
 				
 				g_signal_connect (G_OBJECT (dialog),
 					"response",
@@ -1443,11 +1346,13 @@ spawn_search_command (gchar *command)
 
 		stop_animation ();
 
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_BUTTONS_OK,
-					             _("Error parsing the search command"),
-					             (error != NULL) ? error->message : "");
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+	                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+				                   GTK_MESSAGE_ERROR,
+					           GTK_BUTTONS_OK,
+					           _("Error parsing the search command."),
+					           (error == NULL) ? NULL : error->message,
+					           NULL);
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
@@ -1463,13 +1368,15 @@ spawn_search_command (gchar *command)
 		GtkWidget *dialog;
 		
 		stop_animation ();
-						
-		dialog = gsearchtool_hig_dialog_new (GTK_WINDOW (interface.main_window),
-		                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-						     GTK_BUTTONS_OK,
-					             _("Error running the search command"),
-					             (error != NULL) ? error->message : "");
-
+		
+		dialog = gsearch_alert_dialog_new (GTK_WINDOW (interface.main_window),
+	                                           GTK_DIALOG_DESTROY_WITH_PARENT,
+				                   GTK_MESSAGE_ERROR,
+					           GTK_BUTTONS_OK,
+					           _("Error running the search command."),
+					           (error == NULL) ? NULL : error->message,
+					           NULL);
+							   
 		gtk_dialog_run (GTK_DIALOG (dialog));
 		gtk_widget_destroy (dialog);
 		g_error_free (error);
@@ -1479,6 +1386,7 @@ spawn_search_command (gchar *command)
 	search_command.lock = TRUE;
 	search_command.aborted = FALSE;
 	search_command.running = RUNNING; 
+	search_command.pixbuf_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
 	gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.stop_button);
 	gtk_widget_show (interface.stop_button);
@@ -1487,7 +1395,7 @@ spawn_search_command (gchar *command)
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 	gtk_widget_set_sensitive (interface.results, TRUE);
 	gtk_widget_set_sensitive (interface.additional_constraints, FALSE);
-	gtk_widget_set_sensitive (interface.checkbutton, FALSE);
+	gtk_widget_set_sensitive (interface.expander, FALSE);
 	gtk_widget_set_sensitive (interface.table, FALSE);
 
 	gtk_tree_view_scroll_to_point (GTK_TREE_VIEW(interface.tree), 0, 0);
@@ -1616,7 +1524,7 @@ add_constraint (gint constraint_id, gchar *value, gboolean show_constraint)
 
 	if (show_constraint) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
-			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
+			gtk_expander_set_expanded (GTK_EXPANDER (interface.expander), TRUE);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	} 
@@ -1867,29 +1775,24 @@ create_main_window (void)
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
-	interface.drawing_area = gtk_drawing_area_new ();
-	gtk_box_pack_start (GTK_BOX (vbox), interface.drawing_area, TRUE, FALSE, 0);
-
-	gtk_drawing_area_size (GTK_DRAWING_AREA (interface.drawing_area),
-	                       DEFAULT_ANIMATION_WIDTH,
-			       DEFAULT_ANIMATION_HEIGHT);
+	interface.spinner = gsearch_spinner_new ();
+	gtk_widget_show (interface.spinner);
+	gtk_box_pack_start (GTK_BOX (vbox), interface.spinner, FALSE, FALSE, 0);
+	gsearch_spinner_set_small_mode (GSEARCH_SPINNER (interface.spinner), FALSE);
 			  
-	gtk_drag_source_set (interface.drawing_area, 
+	gtk_drag_source_set (interface.spinner, 
 			     GDK_BUTTON1_MASK,
 			     drag_types, 
 			     G_N_ELEMENTS (drag_types), 
 			     GDK_ACTION_COPY);
 			     
-	gtk_drag_source_set_icon_stock (interface.drawing_area,
+	gtk_drag_source_set_icon_stock (interface.spinner,
 	                                GTK_STOCK_FIND);
 			  
-	g_signal_connect (G_OBJECT (interface.drawing_area), 
+	g_signal_connect (G_OBJECT (interface.spinner), 
 			  "drag_data_get",
 			  G_CALLBACK (drag_data_animation_cb), 
 			  interface.main_window);
-
-	g_signal_connect (interface.drawing_area, "expose-event",
-			  G_CALLBACK (animation_expose_event_cb), NULL);
 	
 	interface.table = gtk_table_new (2, 2, FALSE);
 	gtk_table_set_row_spacings (GTK_TABLE(interface.table), 6);
@@ -1959,14 +1862,21 @@ create_main_window (void)
 	g_free (locale_string);
 	g_free (utf8_string);
 	
-	interface.checkbutton = gtk_check_button_new_with_mnemonic (_("Show more _options"));
-	gtk_box_pack_start (GTK_BOX(window), interface.checkbutton, FALSE, FALSE, 0);
-	g_signal_connect (G_OBJECT (interface.checkbutton),"clicked",
-			  G_CALLBACK (click_check_button_cb), NULL);
-			  
+	interface.expander = gtk_expander_new_with_mnemonic (_("Show more _options"));
+	gtk_box_pack_start (GTK_BOX(window), interface.expander, FALSE, FALSE, 0);
+	g_signal_connect (G_OBJECT (interface.expander),"notify::expanded",
+			  G_CALLBACK (click_expander_cb), NULL);
+	
 	interface.additional_constraints = create_additional_constraint_section ();
 	gtk_box_pack_start (GTK_BOX(window), GTK_WIDGET(interface.additional_constraints), FALSE, FALSE, 0);
 	
+	if (interface.is_gail_loaded)
+	{ 
+		add_atk_namedesc (GTK_WIDGET (interface.expander), _("Show more options"), _("Expands or collapses a list of search options."));
+		add_atk_relation (GTK_WIDGET (interface.additional_constraints), GTK_WIDGET (interface.expander), ATK_RELATION_CONTROLLED_BY);
+		add_atk_relation (GTK_WIDGET (interface.expander), GTK_WIDGET (interface.additional_constraints), ATK_RELATION_CONTROLLER_FOR);
+	}
+	
 	vbox = gtk_vbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (window), vbox, TRUE, TRUE, 0);
 	
@@ -2024,7 +1934,7 @@ register_gsearchtool_icon (GtkIconFactory *factory)
 
 	source = gtk_icon_source_new ();
 
-	gtk_icon_source_set_filename (source, GNOME_ICONDIR"/"GNOME_SEARCH_TOOL_ICON);
+	gtk_icon_source_set_icon_name (source, GNOME_SEARCH_TOOL_ICON);
 
 	icon_set = gtk_icon_set_new ();
 	gtk_icon_set_add_source (icon_set, source);
@@ -2186,7 +2096,7 @@ handle_gconf_settings (void)
 {
 	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_additional_options")) {
 		if (GTK_WIDGET_VISIBLE (interface.additional_constraints) == FALSE) {
-			g_signal_emit_by_name (G_OBJECT(interface.checkbutton), "clicked", 0);
+			gtk_expander_set_expanded (GTK_EXPANDER (interface.expander), TRUE);
 			gtk_widget_show (interface.additional_constraints);
 		}
 	}
@@ -2255,6 +2165,7 @@ main (int 	argc,
 	GnomeProgram *gsearchtool;
 	GnomeClient  *client;
 	GtkWidget    *window;
+	GtkIconInfo  *icon_info;
 
 	memset (&interface, 0, sizeof (interface));
 
@@ -2280,7 +2191,12 @@ main (int 	argc,
 					  GNOME_PARAM_APP_DATADIR, DATADIR,  
 					  NULL);
 	gsearchtool_init_stock_icons ();				  
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/"GNOME_SEARCH_TOOL_ICON);
+	icon_info = gtk_icon_theme_lookup_icon (gtk_icon_theme_get_default (), GNOME_SEARCH_TOOL_ICON, 
+	                                        GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE, 0);
+	if (icon_info) {
+		gnome_window_icon_set_default_from_file (gtk_icon_info_get_filename (icon_info));
+		gtk_icon_info_free (icon_info);
+	}
 
 	if (!bonobo_init_full (&argc, argv, bonobo_activation_orb_get (), NULL, NULL))
 		g_error (_("Cannot initialize bonobo."));
@@ -2322,11 +2238,6 @@ main (int 	argc,
 	
 	gtk_widget_show (interface.main_window);
 	
-	interface.icon_theme = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (interface.icon_theme, TRUE);
-
-	setup_animation_image ();
-	
 	if (handle_popt_args () == FALSE) {
 		handle_gconf_settings (); 
 	}	
